@@ -590,7 +590,7 @@ class FetcherArgs:
             action="store_const",
             const="autoland",
             dest="branch",
-            help="Download from try",
+            help="Download from autoland",
         )
 
         build_group = self.parser.add_argument_group("Build Arguments")
@@ -750,7 +750,7 @@ class Fetcher:
     def __init__(
         self,
         branch: str,
-        build: str,
+        build: Union[str, BuildTask],
         flags: Union[Sequence[bool], BuildFlags],
         platform: Optional[Platform] = None,
         nearest: Optional[BuildSearchOrder] = None,
@@ -1245,6 +1245,11 @@ class Fetcher:
             except FetcherException:
                 self.extract_zip(f"{target}.tests.zip", path=path)
 
+        # used by Pernosco to locate source ('\n' is expected)
+        (path / "taskcluster-build-task").write_bytes(
+            f"{self.task_id}\n".encode("utf-8")
+        )
+
         LOG.info("Extracted into %s", path)
 
     def _write_fuzzmanagerconf(self, target: str, path: Path) -> None:
